gc: The Boehm-Demers-Weiser conservative garbage collector
==========================================================

Description
-----------

The Boehm-Demers-Weiser conservative garbage collector.

License
-------

-  Permissive BSD + GPL 2.0+


Upstream Contact
----------------

Webpage: http://www.hboehm.info/gc/

Email List: bdwgc@lists.opendylan.org

Special Update/Build Instructions
---------------------------------

None.

Patches
~~~~~~~

-  cygwin64.patch: let libgc build on Cygwin64.
